@@ -5,4 +5,4 @@ import matplotlib.pyplot as plt
 m = Basemap(width=12000000,height=9000000,projection='lcc',
             resolution=None,lat_1=45.,lat_2=55,lat_0=50,lon_0=-107.)
 m.bluemarble()
-plt.savefig('background3.png')
+plt.show()
