@@ -25,4 +25,4 @@ m.drawparallels(np.arange(-90.,120.,30.))
 m.drawmeridians(np.arange(0.,360.,60.))
 m.drawmapboundary()
 plt.title('Orthographic Map Showing A Quadrant of the Globe')
-plt.savefig('ortho_partial.png')
+plt.show()
