@@ -12,11 +12,10 @@ x, y = m(*np.meshgrid(lons, lats))
 cs = m.contourf(x,y,etopo,30,cmap=plt.cm.jet)
 # draw coastlines.
 m.drawcoastlines()
-# draw a line around the map region.
-m.drawmapboundary()
 # draw parallels and meridians.
 m.drawparallels(np.arange(-60.,90.,30.),labels=[1,0,0,0])
-m.drawmeridians(np.arange(0.,420.,60.),labels=[0,0,0,1])
+m.drawmeridians(np.arange(0.,360.,60.),labels=[0,0,0,1],fontsize=12)
+m.colorbar(location='bottom',pad='10%')
 # add a title.
 plt.title('Robinson Projection')
 plt.show()
