@@ -34,6 +34,19 @@ m.drawparallels(np.arange(-90,90,30),color='0.5')
 plt.title("Blue Marble image warped from 'cyl' to 'mbtfpq' projection",fontsize=12)
 print('warp to McBryde-Thomas Flat-Polar Quartic map ...')
 
+# create new figure
+fig=plt.figure()
+# define projection centered on North America.
+m = Basemap(projection='hammer',lon_0=-100,resolution='l')
+m.bluemarble(scale=0.5)
+# draw coastlines.
+m.drawcoastlines(linewidth=0.5,color='0.5')
+# draw lat/lon grid lines every 30 degrees.
+m.drawmeridians(np.arange(0,360,60),color='0.5')
+m.drawparallels(np.arange(-90,90,30),color='0.5')
+plt.title("Blue Marble image warped from 'cyl' to 'hammer' projection",fontsize=12)
+print('warp to Hammer map ...')
+
 # create new figure
 fig=plt.figure()
 # define cylindrical equidistant projection.
