@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Coordinate.cpp 3367 2011-05-17 16:50:03Z strk $
+ * $Id: Coordinate.cpp 3521 2011-11-29 14:01:25Z strk $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -18,6 +18,7 @@
 
 #include <sstream>
 #include <string>
+#include <iomanip>
 
 #ifndef GEOS_INLINE
 # include <geos/geom/Coordinate.inl>
@@ -40,7 +41,7 @@ string
 Coordinate::toString() const
 {
 	ostringstream s;
-	s<<*this;
+	s << std::setprecision(17) << *this;
 	return s.str();
 }
 
