@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: pj_init.c 2163 2012-02-21 01:53:19Z warmerdam $
+ * $Id: pj_init.c 2305 2012-12-18 00:31:55Z warmerdam $
  *
  * Project:  PROJ.4
  * Purpose:  Initialize projection object from string definition.  Includes
@@ -36,7 +36,7 @@
 #include <errno.h>
 #include <locale.h>
 
-PJ_CVSID("$Id: pj_init.c 2163 2012-02-21 01:53:19Z warmerdam $");
+PJ_CVSID("$Id: pj_init.c 2305 2012-12-18 00:31:55Z warmerdam $");
 
 /************************************************************************/
 /*                              get_opt()                               */
@@ -257,9 +257,14 @@ pj_init_ctx(projCtx ctx, int argc, char **argv) {
     ctx->last_errno = 0;
     start = NULL;
 
-    old_locale = strdup(setlocale(LC_NUMERIC, NULL));
-    if( strcmp(old_locale,"C") != 0 )
-        setlocale(LC_NUMERIC,"C");
+    old_locale = setlocale(LC_NUMERIC, NULL);
+    if (old_locale != NULL) {
+       if (strcmp(old_locale,"C") != 0) {
+	  setlocale(LC_NUMERIC,"C");
+	  old_locale = strdup(old_locale);
+       }else
+	  old_locale = NULL;
+    }
 
     /* put arguments into internal linked list */
     if (argc <= 0) { pj_ctx_set_errno( ctx, -1 ); goto bum_call; }
@@ -468,9 +473,10 @@ pj_init_ctx(projCtx ctx, int argc, char **argv) {
         PIN = 0;
     }
 
-    if( strcmp(old_locale,"C") != 0 )
-        setlocale(LC_NUMERIC,old_locale);
-    free( (char*)old_locale );
+    if (old_locale != NULL) {
+       setlocale(LC_NUMERIC,old_locale);
+       free( (char*)old_locale );
+    }
 
     return PIN;
 }
@@ -499,10 +505,14 @@ pj_free(PJ *P) {
         /* free array of grid pointers if we have one */
         if( P->gridlist != NULL )
             pj_dalloc( P->gridlist );
-        
+
+        if( P->vgridlist_geoid != NULL )
+            pj_dalloc( P->vgridlist_geoid );
+
+        if( P->catalog != NULL )
+            pj_dalloc( P->catalog );
+
         /* free projection parameters */
         P->pfree(P);
     }
 }
-
-
